summaryrefslogtreecommitdiff
path: root/lib/Target/Sparc/SparcTargetMachine.cpp
diff options
context:
space:
mode:
authorChris Lattner <sabre@nondot.org>2005-06-25 02:48:37 +0000
committerChris Lattner <sabre@nondot.org>2005-06-25 02:48:37 +0000
commit0431c96cec9576611f06c513d6adcab0f950c18c (patch)
treef171a42cc9f00ad1bf9f6d7468156123017fce64 /lib/Target/Sparc/SparcTargetMachine.cpp
parent11f14c8be0946a8fb95189156ff1d64a01ff7da3 (diff)
downloadllvm-0431c96cec9576611f06c513d6adcab0f950c18c.tar.gz
llvm-0431c96cec9576611f06c513d6adcab0f950c18c.tar.bz2
llvm-0431c96cec9576611f06c513d6adcab0f950c18c.tar.xz
Refactor the addPassesToEmitAssembly interface into a addPassesToEmitFile
interface. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@22282 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/Sparc/SparcTargetMachine.cpp')
-rw-r--r--lib/Target/Sparc/SparcTargetMachine.cpp9
1 files changed, 6 insertions, 3 deletions
diff --git a/lib/Target/Sparc/SparcTargetMachine.cpp b/lib/Target/Sparc/SparcTargetMachine.cpp
index 21f86a080a..75c095c7a5 100644
--- a/lib/Target/Sparc/SparcTargetMachine.cpp
+++ b/lib/Target/Sparc/SparcTargetMachine.cpp
@@ -59,11 +59,14 @@ unsigned SparcV8TargetMachine::getModuleMatchQuality(const Module &M) {
return getJITMatchQuality()/2;
}
/// addPassesToEmitAssembly - Add passes to the specified pass manager
/// to implement a static compiler for this target.
///
-bool SparcV8TargetMachine::addPassesToEmitAssembly(PassManager &PM,
- std::ostream &Out) {
+bool SparcV8TargetMachine::addPassesToEmitFile(PassManager &PM,
+ std::ostream &Out,
+ CodeGenFileType FileType) {
+ if (FileType != TargetMachine::AssemblyFile) return true;
+
// FIXME: Implement efficient support for garbage collection intrinsics.
PM.add(createLowerGCPass());
@@ -59,11 +59,14 @@ unsigned SparcV8TargetMachine::getModuleMatchQuality(const Module &M) {
return getJITMatchQuality()/2;
}
-/// addPassesToEmitAssembly - Add passes to the specified pass manager
+/// addPassesToEmitFile - Add passes to the specified pass manager
/// to implement a static compiler for this target.
///